// Library: TimingRelay 
// Author: Shaposhnikov Gennadii
// E-mail: genaonyx@mail.ru
// URL: http://arduino.on.kg/

#if ARDUINO >= 100
  #include "Arduino.h"
 #else
  #include "WProgram.h"
#endif

#include "TimingRelay.h"

TimingRelay::TimingRelay(uint8_t _pin, uint32_t _onDelay, uint32_t _offDelay)
{
  pin = _pin;
  onDelay = _onDelay;
  offDelay = _offDelay;
  pinMode(pin, OUTPUT);
  digitalWrite(pin, LOW);
}

void TimingRelay::loop()
{
  if (startTime) {
    if (Timer(startTime, output ? onDelay : offDelay)) {
      startTime = 0;
      digitalWrite(pin, output);
	  if (autoReset) off();
    }
  }
}

void TimingRelay::set(int _output)
{
  if (output == _output) return;
  output = _output;
  startTime = millis();
  if (!startTime) startTime = 1;
}

int TimingRelay::get()
{
  return digitalRead(pin);
}

void TimingRelay::on()
{
  set(HIGH);
}

void TimingRelay::off()
{
  set(LOW);
}
	
bool TimingRelay::Timer(uint32_t startTime, uint32_t period)
{
  unsigned long currentTime = millis();
  if (currentTime >= startTime) {
    return (currentTime >= (startTime + period));
  } else {
    return (currentTime >= (4294967295 - startTime + period));
  }
}